@@ -132,7 +132,13 @@ $(deriveSafeCopy 1 'base ''Identifier)
 -- * AuthMap
 
 newtype FacebookId_001 = FacebookId_001 { unFacebookId_001 :: Text }
-    deriving (Eq, Ord, Read, Show, Data, Typeable, SafeCopy)
+     deriving (Eq, Ord, Read, Show, Data, Typeable)
+
+instance SafeCopy FacebookId_001 where
+    kind = base
+    getCopy = contain $ (FacebookId_001 . Text.decodeUtf8) <$> safeGet
+    putCopy = contain . safePut . Text.encodeUtf8 . unFacebookId_001
+    errorTypeName _ = "FacebookId_001"
 
 newtype FacebookId_002 = FacebookId_002 { unFacebookId_002 :: B.ByteString }
     deriving (Eq, Ord, Read, Show, Data, Typeable)
